@@ -16,7 +16,7 @@ module Graphics.UI.SDL.TTF.General
     ) where
 
 import Foreign
-import Foreign.C.Types(CInt)
+import Foreign.C.Types(CInt(..))
 
 -- import Graphics.UI.SDL.General (failWithError)
 
